@@ -17,6 +17,7 @@ def _get_kwargs(
     args: Union[Unset, None, str] = UNSET,
     path: Union[Unset, None, str] = UNSET,
     is_flow: Union[Unset, None, bool] = UNSET,
+    path_start: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
@@ -31,6 +32,8 @@ def _get_kwargs(
 
     params["is_flow"] = is_flow
 
+    params["path_start"] = path_start
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -80,6 +83,7 @@ def sync_detailed(
     args: Union[Unset, None, str] = UNSET,
     path: Union[Unset, None, str] = UNSET,
     is_flow: Union[Unset, None, bool] = UNSET,
+    path_start: Union[Unset, None, str] = UNSET,
 ) -> Response[List["ListSchedulesResponse200Item"]]:
     """list schedules
 
@@ -90,6 +94,7 @@ def sync_detailed(
         args (Union[Unset, None, str]):
         path (Union[Unset, None, str]):
         is_flow (Union[Unset, None, bool]):
+        path_start (Union[Unset, None, str]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -106,6 +111,7 @@ def sync_detailed(
         args=args,
         path=path,
         is_flow=is_flow,
+        path_start=path_start,
     )
 
     response = client.get_httpx_client().request(
@@ -124,6 +130,7 @@ def sync(
     args: Union[Unset, None, str] = UNSET,
     path: Union[Unset, None, str] = UNSET,
     is_flow: Union[Unset, None, bool] = UNSET,
+    path_start: Union[Unset, None, str] = UNSET,
 ) -> Optional[List["ListSchedulesResponse200Item"]]:
     """list schedules
 
@@ -134,6 +141,7 @@ def sync(
         args (Union[Unset, None, str]):
         path (Union[Unset, None, str]):
         is_flow (Union[Unset, None, bool]):
+        path_start (Union[Unset, None, str]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -151,6 +159,7 @@ def sync(
         args=args,
         path=path,
         is_flow=is_flow,
+        path_start=path_start,
     ).parsed
 
 
@@ -163,6 +172,7 @@ async def asyncio_detailed(
     args: Union[Unset, None, str] = UNSET,
     path: Union[Unset, None, str] = UNSET,
     is_flow: Union[Unset, None, bool] = UNSET,
+    path_start: Union[Unset, None, str] = UNSET,
 ) -> Response[List["ListSchedulesResponse200Item"]]:
     """list schedules
 
@@ -173,6 +183,7 @@ async def asyncio_detailed(
         args (Union[Unset, None, str]):
         path (Union[Unset, None, str]):
         is_flow (Union[Unset, None, bool]):
+        path_start (Union[Unset, None, str]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -189,6 +200,7 @@ async def asyncio_detailed(
         args=args,
         path=path,
         is_flow=is_flow,
+        path_start=path_start,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -205,6 +217,7 @@ async def asyncio(
     args: Union[Unset, None, str] = UNSET,
     path: Union[Unset, None, str] = UNSET,
     is_flow: Union[Unset, None, bool] = UNSET,
+    path_start: Union[Unset, None, str] = UNSET,
 ) -> Optional[List["ListSchedulesResponse200Item"]]:
     """list schedules
 
@@ -215,6 +228,7 @@ async def asyncio(
         args (Union[Unset, None, str]):
         path (Union[Unset, None, str]):
         is_flow (Union[Unset, None, bool]):
+        path_start (Union[Unset, None, str]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -233,5 +247,6 @@ async def asyncio(
             args=args,
             path=path,
             is_flow=is_flow,
+            path_start=path_start,
         )
     ).parsed
