@@ -6,21 +6,29 @@ import httpx
 from ... import errors
 from ...client import AuthenticatedClient, Client
 from ...models.get_script_by_hash_response_200 import GetScriptByHashResponse200
-from ...types import Response
+from ...types import UNSET, Response, Unset
 
 
 def _get_kwargs(
     workspace: str,
     hash_: str,
+    *,
+    with_starred_info: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
+    params: Dict[str, Any] = {}
+    params["with_starred_info"] = with_starred_info
+
+    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
+
     return {
         "method": "get",
         "url": "/w/{workspace}/scripts/get/h/{hash}".format(
             workspace=workspace,
             hash=hash_,
         ),
+        "params": params,
     }
 
 
@@ -53,12 +61,14 @@ def sync_detailed(
     hash_: str,
     *,
     client: Union[AuthenticatedClient, Client],
+    with_starred_info: Union[Unset, None, bool] = UNSET,
 ) -> Response[GetScriptByHashResponse200]:
     """get script by hash
 
     Args:
         workspace (str):
         hash_ (str):
+        with_starred_info (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -71,6 +81,7 @@ def sync_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         hash_=hash_,
+        with_starred_info=with_starred_info,
     )
 
     response = client.get_httpx_client().request(
@@ -85,12 +96,14 @@ def sync(
     hash_: str,
     *,
     client: Union[AuthenticatedClient, Client],
+    with_starred_info: Union[Unset, None, bool] = UNSET,
 ) -> Optional[GetScriptByHashResponse200]:
     """get script by hash
 
     Args:
         workspace (str):
         hash_ (str):
+        with_starred_info (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -104,6 +117,7 @@ def sync(
         workspace=workspace,
         hash_=hash_,
         client=client,
+        with_starred_info=with_starred_info,
     ).parsed
 
 
@@ -112,12 +126,14 @@ async def asyncio_detailed(
     hash_: str,
     *,
     client: Union[AuthenticatedClient, Client],
+    with_starred_info: Union[Unset, None, bool] = UNSET,
 ) -> Response[GetScriptByHashResponse200]:
     """get script by hash
 
     Args:
         workspace (str):
         hash_ (str):
+        with_starred_info (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -130,6 +146,7 @@ async def asyncio_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         hash_=hash_,
+        with_starred_info=with_starred_info,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -142,12 +159,14 @@ async def asyncio(
     hash_: str,
     *,
     client: Union[AuthenticatedClient, Client],
+    with_starred_info: Union[Unset, None, bool] = UNSET,
 ) -> Optional[GetScriptByHashResponse200]:
     """get script by hash
 
     Args:
         workspace (str):
         hash_ (str):
+        with_starred_info (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -162,5 +181,6 @@ async def asyncio(
             workspace=workspace,
             hash_=hash_,
             client=client,
+            with_starred_info=with_starred_info,
         )
     ).parsed
