@@ -8,8 +8,10 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.forloop_flow_modules_item_mock import ForloopFlowModulesItemMock
     from ..models.forloop_flow_modules_item_retry import ForloopFlowModulesItemRetry
+    from ..models.forloop_flow_modules_item_skip_if import ForloopFlowModulesItemSkipIf
     from ..models.forloop_flow_modules_item_sleep_type_0 import ForloopFlowModulesItemSleepType0
     from ..models.forloop_flow_modules_item_sleep_type_1 import ForloopFlowModulesItemSleepType1
+    from ..models.forloop_flow_modules_item_stop_after_all_iters_if import ForloopFlowModulesItemStopAfterAllItersIf
     from ..models.forloop_flow_modules_item_stop_after_if import ForloopFlowModulesItemStopAfterIf
     from ..models.forloop_flow_modules_item_suspend import ForloopFlowModulesItemSuspend
 
@@ -24,6 +26,8 @@ class ForloopFlowModulesItem:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, ForloopFlowModulesItemStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, ForloopFlowModulesItemStopAfterAllItersIf]):
+        skip_if (Union[Unset, ForloopFlowModulesItemSkipIf]):
         sleep (Union['ForloopFlowModulesItemSleepType0', 'ForloopFlowModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
         timeout (Union[Unset, float]):
@@ -39,6 +43,8 @@ class ForloopFlowModulesItem:
     id: str
     value: Any
     stop_after_if: Union[Unset, "ForloopFlowModulesItemStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "ForloopFlowModulesItemStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "ForloopFlowModulesItemSkipIf"] = UNSET
     sleep: Union["ForloopFlowModulesItemSleepType0", "ForloopFlowModulesItemSleepType1", Unset] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
     timeout: Union[Unset, float] = UNSET
@@ -60,6 +66,14 @@ class ForloopFlowModulesItem:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -102,6 +116,10 @@ class ForloopFlowModulesItem:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -129,8 +147,10 @@ class ForloopFlowModulesItem:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.forloop_flow_modules_item_mock import ForloopFlowModulesItemMock
         from ..models.forloop_flow_modules_item_retry import ForloopFlowModulesItemRetry
+        from ..models.forloop_flow_modules_item_skip_if import ForloopFlowModulesItemSkipIf
         from ..models.forloop_flow_modules_item_sleep_type_0 import ForloopFlowModulesItemSleepType0
         from ..models.forloop_flow_modules_item_sleep_type_1 import ForloopFlowModulesItemSleepType1
+        from ..models.forloop_flow_modules_item_stop_after_all_iters_if import ForloopFlowModulesItemStopAfterAllItersIf
         from ..models.forloop_flow_modules_item_stop_after_if import ForloopFlowModulesItemStopAfterIf
         from ..models.forloop_flow_modules_item_suspend import ForloopFlowModulesItemSuspend
 
@@ -146,6 +166,20 @@ class ForloopFlowModulesItem:
         else:
             stop_after_if = ForloopFlowModulesItemStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, ForloopFlowModulesItemStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = ForloopFlowModulesItemStopAfterAllItersIf.from_dict(_stop_after_all_iters_if)
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, ForloopFlowModulesItemSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = ForloopFlowModulesItemSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union["ForloopFlowModulesItemSleepType0", "ForloopFlowModulesItemSleepType1", Unset]:
@@ -214,6 +248,8 @@ class ForloopFlowModulesItem:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
