@@ -12,12 +12,18 @@ if TYPE_CHECKING:
     from ..models.get_flow_by_path_response_200_value_modules_item_retry import (
         GetFlowByPathResponse200ValueModulesItemRetry,
     )
+    from ..models.get_flow_by_path_response_200_value_modules_item_skip_if import (
+        GetFlowByPathResponse200ValueModulesItemSkipIf,
+    )
     from ..models.get_flow_by_path_response_200_value_modules_item_sleep_type_0 import (
         GetFlowByPathResponse200ValueModulesItemSleepType0,
     )
     from ..models.get_flow_by_path_response_200_value_modules_item_sleep_type_1 import (
         GetFlowByPathResponse200ValueModulesItemSleepType1,
     )
+    from ..models.get_flow_by_path_response_200_value_modules_item_stop_after_all_iters_if import (
+        GetFlowByPathResponse200ValueModulesItemStopAfterAllItersIf,
+    )
     from ..models.get_flow_by_path_response_200_value_modules_item_stop_after_if import (
         GetFlowByPathResponse200ValueModulesItemStopAfterIf,
     )
@@ -36,6 +42,8 @@ class GetFlowByPathResponse200ValueModulesItem:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, GetFlowByPathResponse200ValueModulesItemStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, GetFlowByPathResponse200ValueModulesItemStopAfterAllItersIf]):
+        skip_if (Union[Unset, GetFlowByPathResponse200ValueModulesItemSkipIf]):
         sleep (Union['GetFlowByPathResponse200ValueModulesItemSleepType0',
             'GetFlowByPathResponse200ValueModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
@@ -52,6 +60,8 @@ class GetFlowByPathResponse200ValueModulesItem:
     id: str
     value: Any
     stop_after_if: Union[Unset, "GetFlowByPathResponse200ValueModulesItemStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "GetFlowByPathResponse200ValueModulesItemStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "GetFlowByPathResponse200ValueModulesItemSkipIf"] = UNSET
     sleep: Union[
         "GetFlowByPathResponse200ValueModulesItemSleepType0",
         "GetFlowByPathResponse200ValueModulesItemSleepType1",
@@ -79,6 +89,14 @@ class GetFlowByPathResponse200ValueModulesItem:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -121,6 +139,10 @@ class GetFlowByPathResponse200ValueModulesItem:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -152,12 +174,18 @@ class GetFlowByPathResponse200ValueModulesItem:
         from ..models.get_flow_by_path_response_200_value_modules_item_retry import (
             GetFlowByPathResponse200ValueModulesItemRetry,
         )
+        from ..models.get_flow_by_path_response_200_value_modules_item_skip_if import (
+            GetFlowByPathResponse200ValueModulesItemSkipIf,
+        )
         from ..models.get_flow_by_path_response_200_value_modules_item_sleep_type_0 import (
             GetFlowByPathResponse200ValueModulesItemSleepType0,
         )
         from ..models.get_flow_by_path_response_200_value_modules_item_sleep_type_1 import (
             GetFlowByPathResponse200ValueModulesItemSleepType1,
         )
+        from ..models.get_flow_by_path_response_200_value_modules_item_stop_after_all_iters_if import (
+            GetFlowByPathResponse200ValueModulesItemStopAfterAllItersIf,
+        )
         from ..models.get_flow_by_path_response_200_value_modules_item_stop_after_if import (
             GetFlowByPathResponse200ValueModulesItemStopAfterIf,
         )
@@ -177,6 +205,22 @@ class GetFlowByPathResponse200ValueModulesItem:
         else:
             stop_after_if = GetFlowByPathResponse200ValueModulesItemStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, GetFlowByPathResponse200ValueModulesItemStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = GetFlowByPathResponse200ValueModulesItemStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, GetFlowByPathResponse200ValueModulesItemSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = GetFlowByPathResponse200ValueModulesItemSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union[
@@ -249,6 +293,8 @@ class GetFlowByPathResponse200ValueModulesItem:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
