@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -6,6 +6,10 @@ from attrs import field as _attrs_field
 from ..models.large_file_storage_type import LargeFileStorageType
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.large_file_storage_secondary_storage import LargeFileStorageSecondaryStorage
+
+
 T = TypeVar("T", bound="LargeFileStorage")
 
 
@@ -16,13 +20,17 @@ class LargeFileStorage:
         type (Union[Unset, LargeFileStorageType]):
         s3_resource_path (Union[Unset, str]):
         azure_blob_resource_path (Union[Unset, str]):
+        gcs_resource_path (Union[Unset, str]):
         public_resource (Union[Unset, bool]):
+        secondary_storage (Union[Unset, LargeFileStorageSecondaryStorage]):
     """
 
     type: Union[Unset, LargeFileStorageType] = UNSET
     s3_resource_path: Union[Unset, str] = UNSET
     azure_blob_resource_path: Union[Unset, str] = UNSET
+    gcs_resource_path: Union[Unset, str] = UNSET
     public_resource: Union[Unset, bool] = UNSET
+    secondary_storage: Union[Unset, "LargeFileStorageSecondaryStorage"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -32,7 +40,11 @@ class LargeFileStorage:
 
         s3_resource_path = self.s3_resource_path
         azure_blob_resource_path = self.azure_blob_resource_path
+        gcs_resource_path = self.gcs_resource_path
         public_resource = self.public_resource
+        secondary_storage: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.secondary_storage, Unset):
+            secondary_storage = self.secondary_storage.to_dict()
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -43,13 +55,19 @@ class LargeFileStorage:
             field_dict["s3_resource_path"] = s3_resource_path
         if azure_blob_resource_path is not UNSET:
             field_dict["azure_blob_resource_path"] = azure_blob_resource_path
+        if gcs_resource_path is not UNSET:
+            field_dict["gcs_resource_path"] = gcs_resource_path
         if public_resource is not UNSET:
             field_dict["public_resource"] = public_resource
+        if secondary_storage is not UNSET:
+            field_dict["secondary_storage"] = secondary_storage
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.large_file_storage_secondary_storage import LargeFileStorageSecondaryStorage
+
         d = src_dict.copy()
         _type = d.pop("type", UNSET)
         type: Union[Unset, LargeFileStorageType]
@@ -62,13 +80,24 @@ class LargeFileStorage:
 
         azure_blob_resource_path = d.pop("azure_blob_resource_path", UNSET)
 
+        gcs_resource_path = d.pop("gcs_resource_path", UNSET)
+
         public_resource = d.pop("public_resource", UNSET)
 
+        _secondary_storage = d.pop("secondary_storage", UNSET)
+        secondary_storage: Union[Unset, LargeFileStorageSecondaryStorage]
+        if isinstance(_secondary_storage, Unset):
+            secondary_storage = UNSET
+        else:
+            secondary_storage = LargeFileStorageSecondaryStorage.from_dict(_secondary_storage)
+
         large_file_storage = cls(
             type=type,
             s3_resource_path=s3_resource_path,
             azure_blob_resource_path=azure_blob_resource_path,
+            gcs_resource_path=gcs_resource_path,
             public_resource=public_resource,
+            secondary_storage=secondary_storage,
         )
 
         large_file_storage.additional_properties = d
