@@ -55,6 +55,10 @@ class ListCompletedJobsResponse200Item:
         mem_peak (Union[Unset, int]):
         priority (Union[Unset, int]):
         labels (Union[Unset, List[str]]):
+        self_wait_time_ms (Union[Unset, float]):
+        aggregate_wait_time_ms (Union[Unset, float]):
+        preprocessed (Union[Unset, bool]):
+        worker (Union[Unset, str]):
     """
 
     id: str
@@ -89,6 +93,10 @@ class ListCompletedJobsResponse200Item:
     mem_peak: Union[Unset, int] = UNSET
     priority: Union[Unset, int] = UNSET
     labels: Union[Unset, List[str]] = UNSET
+    self_wait_time_ms: Union[Unset, float] = UNSET
+    aggregate_wait_time_ms: Union[Unset, float] = UNSET
+    preprocessed: Union[Unset, bool] = UNSET
+    worker: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -142,6 +150,11 @@ class ListCompletedJobsResponse200Item:
         if not isinstance(self.labels, Unset):
             labels = self.labels
 
+        self_wait_time_ms = self.self_wait_time_ms
+        aggregate_wait_time_ms = self.aggregate_wait_time_ms
+        preprocessed = self.preprocessed
+        worker = self.worker
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -198,6 +211,14 @@ class ListCompletedJobsResponse200Item:
             field_dict["priority"] = priority
         if labels is not UNSET:
             field_dict["labels"] = labels
+        if self_wait_time_ms is not UNSET:
+            field_dict["self_wait_time_ms"] = self_wait_time_ms
+        if aggregate_wait_time_ms is not UNSET:
+            field_dict["aggregate_wait_time_ms"] = aggregate_wait_time_ms
+        if preprocessed is not UNSET:
+            field_dict["preprocessed"] = preprocessed
+        if worker is not UNSET:
+            field_dict["worker"] = worker
 
         return field_dict
 
@@ -294,6 +315,14 @@ class ListCompletedJobsResponse200Item:
 
         labels = cast(List[str], d.pop("labels", UNSET))
 
+        self_wait_time_ms = d.pop("self_wait_time_ms", UNSET)
+
+        aggregate_wait_time_ms = d.pop("aggregate_wait_time_ms", UNSET)
+
+        preprocessed = d.pop("preprocessed", UNSET)
+
+        worker = d.pop("worker", UNSET)
+
         list_completed_jobs_response_200_item = cls(
             id=id,
             created_by=created_by,
@@ -327,6 +356,10 @@ class ListCompletedJobsResponse200Item:
             mem_peak=mem_peak,
             priority=priority,
             labels=labels,
+            self_wait_time_ms=self_wait_time_ms,
+            aggregate_wait_time_ms=aggregate_wait_time_ms,
+            preprocessed=preprocessed,
+            worker=worker,
         )
 
         list_completed_jobs_response_200_item.additional_properties = d
