@@ -12,12 +12,18 @@ if TYPE_CHECKING:
     from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_retry import (
         ListCompletedJobsResponse200ItemRawFlowFailureModuleRetry,
     )
+    from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_skip_if import (
+        ListCompletedJobsResponse200ItemRawFlowFailureModuleSkipIf,
+    )
     from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_sleep_type_0 import (
         ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0,
     )
     from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_sleep_type_1 import (
         ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1,
     )
+    from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_stop_after_all_iters_if import (
+        ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterAllItersIf,
+    )
     from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_stop_after_if import (
         ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf,
     )
@@ -36,6 +42,8 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterAllItersIf]):
+        skip_if (Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleSkipIf]):
         sleep (Union['ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0',
             'ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
@@ -52,6 +60,10 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
     id: str
     value: Any
     stop_after_if: Union[Unset, "ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[
+        Unset, "ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterAllItersIf"
+    ] = UNSET
+    skip_if: Union[Unset, "ListCompletedJobsResponse200ItemRawFlowFailureModuleSkipIf"] = UNSET
     sleep: Union[
         "ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0",
         "ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1",
@@ -79,6 +91,14 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -121,6 +141,10 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -152,12 +176,18 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
         from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_retry import (
             ListCompletedJobsResponse200ItemRawFlowFailureModuleRetry,
         )
+        from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_skip_if import (
+            ListCompletedJobsResponse200ItemRawFlowFailureModuleSkipIf,
+        )
         from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_sleep_type_0 import (
             ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType0,
         )
         from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_sleep_type_1 import (
             ListCompletedJobsResponse200ItemRawFlowFailureModuleSleepType1,
         )
+        from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_stop_after_all_iters_if import (
+            ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterAllItersIf,
+        )
         from ..models.list_completed_jobs_response_200_item_raw_flow_failure_module_stop_after_if import (
             ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf,
         )
@@ -177,6 +207,22 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
         else:
             stop_after_if = ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = ListCompletedJobsResponse200ItemRawFlowFailureModuleStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModuleSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = ListCompletedJobsResponse200ItemRawFlowFailureModuleSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union[
@@ -251,6 +297,8 @@ class ListCompletedJobsResponse200ItemRawFlowFailureModule:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
