@@ -1,7 +1,9 @@
+import datetime
 from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
+from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
 
@@ -9,6 +11,7 @@ if TYPE_CHECKING:
     from ..models.new_schedule_args import NewScheduleArgs
     from ..models.new_schedule_on_failure_extra_args import NewScheduleOnFailureExtraArgs
     from ..models.new_schedule_on_recovery_extra_args import NewScheduleOnRecoveryExtraArgs
+    from ..models.new_schedule_on_success_extra_args import NewScheduleOnSuccessExtraArgs
     from ..models.new_schedule_retry import NewScheduleRetry
 
 
@@ -33,11 +36,16 @@ class NewSchedule:
         on_recovery (Union[Unset, str]):
         on_recovery_times (Union[Unset, float]):
         on_recovery_extra_args (Union[Unset, NewScheduleOnRecoveryExtraArgs]):
+        on_success (Union[Unset, str]):
+        on_success_extra_args (Union[Unset, NewScheduleOnSuccessExtraArgs]):
         ws_error_handler_muted (Union[Unset, bool]):
         retry (Union[Unset, NewScheduleRetry]):
         no_flow_overlap (Union[Unset, bool]):
         summary (Union[Unset, str]):
+        description (Union[Unset, str]):
         tag (Union[Unset, str]):
+        paused_until (Union[Unset, datetime.datetime]):
+        cron_version (Union[Unset, str]):
     """
 
     path: str
@@ -54,11 +62,16 @@ class NewSchedule:
     on_recovery: Union[Unset, str] = UNSET
     on_recovery_times: Union[Unset, float] = UNSET
     on_recovery_extra_args: Union[Unset, "NewScheduleOnRecoveryExtraArgs"] = UNSET
+    on_success: Union[Unset, str] = UNSET
+    on_success_extra_args: Union[Unset, "NewScheduleOnSuccessExtraArgs"] = UNSET
     ws_error_handler_muted: Union[Unset, bool] = UNSET
     retry: Union[Unset, "NewScheduleRetry"] = UNSET
     no_flow_overlap: Union[Unset, bool] = UNSET
     summary: Union[Unset, str] = UNSET
+    description: Union[Unset, str] = UNSET
     tag: Union[Unset, str] = UNSET
+    paused_until: Union[Unset, datetime.datetime] = UNSET
+    cron_version: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -83,6 +96,11 @@ class NewSchedule:
         if not isinstance(self.on_recovery_extra_args, Unset):
             on_recovery_extra_args = self.on_recovery_extra_args.to_dict()
 
+        on_success = self.on_success
+        on_success_extra_args: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.on_success_extra_args, Unset):
+            on_success_extra_args = self.on_success_extra_args.to_dict()
+
         ws_error_handler_muted = self.ws_error_handler_muted
         retry: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.retry, Unset):
@@ -90,7 +108,13 @@ class NewSchedule:
 
         no_flow_overlap = self.no_flow_overlap
         summary = self.summary
+        description = self.description
         tag = self.tag
+        paused_until: Union[Unset, str] = UNSET
+        if not isinstance(self.paused_until, Unset):
+            paused_until = self.paused_until.isoformat()
+
+        cron_version = self.cron_version
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -120,6 +144,10 @@ class NewSchedule:
             field_dict["on_recovery_times"] = on_recovery_times
         if on_recovery_extra_args is not UNSET:
             field_dict["on_recovery_extra_args"] = on_recovery_extra_args
+        if on_success is not UNSET:
+            field_dict["on_success"] = on_success
+        if on_success_extra_args is not UNSET:
+            field_dict["on_success_extra_args"] = on_success_extra_args
         if ws_error_handler_muted is not UNSET:
             field_dict["ws_error_handler_muted"] = ws_error_handler_muted
         if retry is not UNSET:
@@ -128,8 +156,14 @@ class NewSchedule:
             field_dict["no_flow_overlap"] = no_flow_overlap
         if summary is not UNSET:
             field_dict["summary"] = summary
+        if description is not UNSET:
+            field_dict["description"] = description
         if tag is not UNSET:
             field_dict["tag"] = tag
+        if paused_until is not UNSET:
+            field_dict["paused_until"] = paused_until
+        if cron_version is not UNSET:
+            field_dict["cron_version"] = cron_version
 
         return field_dict
 
@@ -138,6 +172,7 @@ class NewSchedule:
         from ..models.new_schedule_args import NewScheduleArgs
         from ..models.new_schedule_on_failure_extra_args import NewScheduleOnFailureExtraArgs
         from ..models.new_schedule_on_recovery_extra_args import NewScheduleOnRecoveryExtraArgs
+        from ..models.new_schedule_on_success_extra_args import NewScheduleOnSuccessExtraArgs
         from ..models.new_schedule_retry import NewScheduleRetry
 
         d = src_dict.copy()
@@ -179,6 +214,15 @@ class NewSchedule:
         else:
             on_recovery_extra_args = NewScheduleOnRecoveryExtraArgs.from_dict(_on_recovery_extra_args)
 
+        on_success = d.pop("on_success", UNSET)
+
+        _on_success_extra_args = d.pop("on_success_extra_args", UNSET)
+        on_success_extra_args: Union[Unset, NewScheduleOnSuccessExtraArgs]
+        if isinstance(_on_success_extra_args, Unset):
+            on_success_extra_args = UNSET
+        else:
+            on_success_extra_args = NewScheduleOnSuccessExtraArgs.from_dict(_on_success_extra_args)
+
         ws_error_handler_muted = d.pop("ws_error_handler_muted", UNSET)
 
         _retry = d.pop("retry", UNSET)
@@ -192,8 +236,19 @@ class NewSchedule:
 
         summary = d.pop("summary", UNSET)
 
+        description = d.pop("description", UNSET)
+
         tag = d.pop("tag", UNSET)
 
+        _paused_until = d.pop("paused_until", UNSET)
+        paused_until: Union[Unset, datetime.datetime]
+        if isinstance(_paused_until, Unset):
+            paused_until = UNSET
+        else:
+            paused_until = isoparse(_paused_until)
+
+        cron_version = d.pop("cron_version", UNSET)
+
         new_schedule = cls(
             path=path,
             schedule=schedule,
@@ -209,11 +264,16 @@ class NewSchedule:
             on_recovery=on_recovery,
             on_recovery_times=on_recovery_times,
             on_recovery_extra_args=on_recovery_extra_args,
+            on_success=on_success,
+            on_success_extra_args=on_success_extra_args,
             ws_error_handler_muted=ws_error_handler_muted,
             retry=retry,
             no_flow_overlap=no_flow_overlap,
             summary=summary,
+            description=description,
             tag=tag,
+            paused_until=paused_until,
+            cron_version=cron_version,
         )
 
         new_schedule.additional_properties = d
