@@ -47,6 +47,8 @@ class NewScriptWithDraft:
         visible_to_runner_only (Union[Unset, bool]):
         no_main_func (Union[Unset, bool]):
         codebase (Union[Unset, str]):
+        has_preprocessor (Union[Unset, bool]):
+        on_behalf_of_email (Union[Unset, str]):
         draft (Union[Unset, NewScriptWithDraftDraft]):
     """
 
@@ -78,6 +80,8 @@ class NewScriptWithDraft:
     visible_to_runner_only: Union[Unset, bool] = UNSET
     no_main_func: Union[Unset, bool] = UNSET
     codebase: Union[Unset, str] = UNSET
+    has_preprocessor: Union[Unset, bool] = UNSET
+    on_behalf_of_email: Union[Unset, str] = UNSET
     draft: Union[Unset, "NewScriptWithDraftDraft"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -120,6 +124,8 @@ class NewScriptWithDraft:
         visible_to_runner_only = self.visible_to_runner_only
         no_main_func = self.no_main_func
         codebase = self.codebase
+        has_preprocessor = self.has_preprocessor
+        on_behalf_of_email = self.on_behalf_of_email
         draft: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.draft, Unset):
             draft = self.draft.to_dict()
@@ -180,6 +186,10 @@ class NewScriptWithDraft:
             field_dict["no_main_func"] = no_main_func
         if codebase is not UNSET:
             field_dict["codebase"] = codebase
+        if has_preprocessor is not UNSET:
+            field_dict["has_preprocessor"] = has_preprocessor
+        if on_behalf_of_email is not UNSET:
+            field_dict["on_behalf_of_email"] = on_behalf_of_email
         if draft is not UNSET:
             field_dict["draft"] = draft
 
@@ -257,6 +267,10 @@ class NewScriptWithDraft:
 
         codebase = d.pop("codebase", UNSET)
 
+        has_preprocessor = d.pop("has_preprocessor", UNSET)
+
+        on_behalf_of_email = d.pop("on_behalf_of_email", UNSET)
+
         _draft = d.pop("draft", UNSET)
         draft: Union[Unset, NewScriptWithDraftDraft]
         if isinstance(_draft, Unset):
@@ -293,6 +307,8 @@ class NewScriptWithDraft:
             visible_to_runner_only=visible_to_runner_only,
             no_main_func=no_main_func,
             codebase=codebase,
+            has_preprocessor=has_preprocessor,
+            on_behalf_of_email=on_behalf_of_email,
             draft=draft,
         )
 
