@@ -8,8 +8,12 @@ from ..types import UNSET, Unset
 if TYPE_CHECKING:
     from ..models.open_flow_w_path_value_failure_module_mock import OpenFlowWPathValueFailureModuleMock
     from ..models.open_flow_w_path_value_failure_module_retry import OpenFlowWPathValueFailureModuleRetry
+    from ..models.open_flow_w_path_value_failure_module_skip_if import OpenFlowWPathValueFailureModuleSkipIf
     from ..models.open_flow_w_path_value_failure_module_sleep_type_0 import OpenFlowWPathValueFailureModuleSleepType0
     from ..models.open_flow_w_path_value_failure_module_sleep_type_1 import OpenFlowWPathValueFailureModuleSleepType1
+    from ..models.open_flow_w_path_value_failure_module_stop_after_all_iters_if import (
+        OpenFlowWPathValueFailureModuleStopAfterAllItersIf,
+    )
     from ..models.open_flow_w_path_value_failure_module_stop_after_if import OpenFlowWPathValueFailureModuleStopAfterIf
     from ..models.open_flow_w_path_value_failure_module_suspend import OpenFlowWPathValueFailureModuleSuspend
 
@@ -24,6 +28,8 @@ class OpenFlowWPathValueFailureModule:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, OpenFlowWPathValueFailureModuleStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, OpenFlowWPathValueFailureModuleStopAfterAllItersIf]):
+        skip_if (Union[Unset, OpenFlowWPathValueFailureModuleSkipIf]):
         sleep (Union['OpenFlowWPathValueFailureModuleSleepType0', 'OpenFlowWPathValueFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
         timeout (Union[Unset, float]):
@@ -39,6 +45,8 @@ class OpenFlowWPathValueFailureModule:
     id: str
     value: Any
     stop_after_if: Union[Unset, "OpenFlowWPathValueFailureModuleStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "OpenFlowWPathValueFailureModuleStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "OpenFlowWPathValueFailureModuleSkipIf"] = UNSET
     sleep: Union[
         "OpenFlowWPathValueFailureModuleSleepType0", "OpenFlowWPathValueFailureModuleSleepType1", Unset
     ] = UNSET
@@ -64,6 +72,14 @@ class OpenFlowWPathValueFailureModule:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -106,6 +122,10 @@ class OpenFlowWPathValueFailureModule:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -133,12 +153,16 @@ class OpenFlowWPathValueFailureModule:
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         from ..models.open_flow_w_path_value_failure_module_mock import OpenFlowWPathValueFailureModuleMock
         from ..models.open_flow_w_path_value_failure_module_retry import OpenFlowWPathValueFailureModuleRetry
+        from ..models.open_flow_w_path_value_failure_module_skip_if import OpenFlowWPathValueFailureModuleSkipIf
         from ..models.open_flow_w_path_value_failure_module_sleep_type_0 import (
             OpenFlowWPathValueFailureModuleSleepType0,
         )
         from ..models.open_flow_w_path_value_failure_module_sleep_type_1 import (
             OpenFlowWPathValueFailureModuleSleepType1,
         )
+        from ..models.open_flow_w_path_value_failure_module_stop_after_all_iters_if import (
+            OpenFlowWPathValueFailureModuleStopAfterAllItersIf,
+        )
         from ..models.open_flow_w_path_value_failure_module_stop_after_if import (
             OpenFlowWPathValueFailureModuleStopAfterIf,
         )
@@ -156,6 +180,22 @@ class OpenFlowWPathValueFailureModule:
         else:
             stop_after_if = OpenFlowWPathValueFailureModuleStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, OpenFlowWPathValueFailureModuleStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = OpenFlowWPathValueFailureModuleStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, OpenFlowWPathValueFailureModuleSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = OpenFlowWPathValueFailureModuleSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union["OpenFlowWPathValueFailureModuleSleepType0", "OpenFlowWPathValueFailureModuleSleepType1", Unset]:
@@ -224,6 +264,8 @@ class OpenFlowWPathValueFailureModule:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
